@@ -9,17 +9,17 @@
 #' @return \code{logical} vector of length nrow(E), TRUE for edits containing \code{var}
 #' @export
 contains <- function(E,var=NULL,...){
-    if (nedits(E)==0){
-        if ( is.null(var) ) var <- getVars(E)
-        return(
-            array(
-                logical(0),
-                dim=c(0,length(var)),
-                dimnames=list(edit=NULL,variable=var)
-            )
-        )
-    }
-    UseMethod('contains')
+  if (nedits(E)==0){
+    if ( is.null(var) ) var <- getVars(E)
+    return(
+      array(
+        logical(0),
+        dim=c(0,length(var)),
+        dimnames=list(edit=NULL,variable=var)
+      )
+    )
+  }
+  UseMethod('contains')
 }
 
 
@@ -54,9 +54,12 @@ contains.editmatrix <- function(E, var=NULL, tol=sqrt(.Machine$double.eps), ...)
     } else {
       stopifnot(all(var %in% vars))
     }
-    
-    u <- abs(A[,var,drop=FALSE]) > tol
-    dimnames(u) <- list(edit=rownames(E),variable=var) 
+    if ( length(var) > 0 ){ 
+      u <- abs(A[,var,drop=FALSE]) > tol
+    } else {
+      u <- array(FALSE,dim=c(nrow(A),0))
+    } 
+    dimnames(u) <- list(edit=rownames(E),variable=var)
     u
 }
 
